@@ -3,34 +3,23 @@ use warnings;
 
 package Dist::Zilla::Plugin::Run::Role::Runner;
 # ABSTRACT: Role for the packages of Dist::Zilla::Plugin::Run
-$Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.030';
+$Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.031';
 use Moose::Role;
 use namespace::autoclean;
 use File::Spec (); # core
 use Config     (); # core
-use List::Util 1.33 'any';
 
 has perlpath => (
     is      => 'ro',
     isa     => 'Str',
+    lazy    => 1,
     builder => 'current_perl_path',
 );
 
 has censor_commands => (
     is => 'ro',
     isa => 'Bool',
-    lazy => 1,
-    default => sub {
-        my $self = shift;
-
-        # look for user:password URIs
-        my ($command) = grep {
-            any { /\b\w+:[^@]+@\b/ } @{ $self->$_ }
-        } qw(run run_if_trial run_no_trial run_if_release run_no_release);
-
-        $self->log("found a $command command that looks like it contains a password: redacting this from dumped configs!") if $command;
-        $command ? 1 : 0;
-    },
+    default => 0,
 );
 
 has run => (
@@ -81,10 +70,12 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
+        (map { $_ => $self->$_ } qw(fatal_errors)),
         map {
-            @{$self->$_}
-            ? ( $_ => ( $self->censor_commands ? 'REDACTED' : $self->$_ ) )
-            : ()
+            @{ $self->$_ }
+                # look for user:password URIs
+                ? ( $_ => [ map { $self->censor_commands || /\b\w+:[^@]+@\b/ ? 'REDACTED' : $_ } @{ $self->$_ } ] )
+                : ()
         }
         qw(run run_if_trial run_no_trial run_if_release run_no_release eval),
     };
@@ -259,15 +250,7 @@ sub build_formatter {
     return String::Formatter->new({ codes => $codes });
 }
 
-sub current_perl_path {
-    # see perlvar $^X for why we don't just use that here
-    my $perl = $Config::Config{perlpath};
-    if ($^O ne 'VMS') {
-        $perl .= $Config::Config{_exe}
-            unless $perl =~ m/$Config::Config{_exe}$/i;
-    }
-    return $perl;
-}
+sub current_perl_path { $^X }
 
 #pod =head1 DESCRIPTION
 #pod
@@ -290,7 +273,7 @@ Dist::Zilla::Plugin::Run::Role::Runner - Role for the packages of Dist::Zilla::P
 
 =head1 VERSION
 
-version 0.030
+version 0.031
 
 =head1 DESCRIPTION
 
